@@ -1,3 +1,6 @@
+#ifndef AGENDAPLUG_H
+#define AGENDAPLUG_H
+
 #include "ui_AgendaPlug.h"
 
 #include <QDate>
@@ -17,15 +20,13 @@ public:
     QString title() const { return tr("Agenda"); }
     bool isRotatable() const { return true; }
 
-    void onActivated();
+    void onChange();
 
     void setDate(QDate date);
 
 private:
     Ui::AgendaPlug *ui;
 
-    QDate date;
-
     vector<CComponent*> components;
 
     void cleanup();
@@ -35,3 +36,5 @@ private slots:
     void selectDay();
     void gotoToday();
 };
+
+#endif // AGENDAPLUG_H
