@@ -31,7 +31,10 @@ private slots:
     void gotoNextEvent();
 
     void editEvent();
+    void cloneEvent();
     void deleteEvent();
+
+    void enableLinks(bool enalbe);
 };
 
 #endif // EVENTWINDOW_H
