@@ -2,6 +2,7 @@
 
 #include <QMaemo5Style>
 
+#include <QSettings>
 #include <QDateTime>
 #include <QShortcut>
 #include <QTimer>
@@ -39,10 +40,15 @@ TodoWindow::TodoWindow(CTodo *todo, QWidget *parent) :
     ui->descriptionInfo->setPalette(palette);
 
     connect(ui->editAction, SIGNAL(triggered()), this, SLOT(editTodo()));
+    connect(ui->cloneAction, SIGNAL(triggered()), this, SLOT(cloneTodo()));
     connect(ui->deleteAction, SIGNAL(triggered()), this, SLOT(deleteTodo()));
 
+    connect(ui->linksAction, SIGNAL(toggled(bool)), this, SLOT(enableLinks(bool)));
+
     connect(new QShortcut(QKeySequence(Qt::Key_Backspace), this), SIGNAL(activated()), this, SLOT(close()));
 
+    ui->linksAction->setChecked(QSettings().value("AutomaticLinks", false).toBool());
+
     reload();
 }
 
@@ -139,11 +145,24 @@ void TodoWindow::editTodo()
     ChangeManager::edit(this, todo);
 }
 
+void TodoWindow::cloneTodo()
+{
+    ChangeManager::clone(this, todo);
+}
+
 void TodoWindow::deleteTodo()
 {
     ChangeManager::drop(this, todo);
 }
 
+void TodoWindow::enableLinks(bool enable)
+{
+    QSettings().setValue("AutomaticLinks", enable);
+
+    ui->summaryInfo->enableLinks(enable);
+    ui->descriptionInfo->enableLinks(enable);
+}
+
 void TodoWindow::closeEvent(QCloseEvent *e)
 {
     if (todo && todo->getStatus() != ui->doneBox->isChecked()) {
