@@ -29,7 +29,10 @@ private:
 
 private slots:
     void editTodo();
+    void cloneTodo();
     void deleteTodo();
+
+    void enableLinks(bool enable);
 };
 
 #endif // TODOWINDOW_H
