@@ -7,10 +7,6 @@
 
 #include "ChangeManager.h"
 
-namespace Ui {
-    class TodosPlug;
-}
-
 class TodosPlug : public Plug
 {
     Q_OBJECT
@@ -22,7 +18,7 @@ public:
     QString title() const;
     bool isRotatable() const { return true; }
 
-    void onActivated();
+    void onChange();
 
 private:
     Ui::TodosPlug *ui;
