@@ -424,12 +424,12 @@ päivä</translation>
         <translation>Kuvaus</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="69"/>
+        <location filename="../EventEditDialog.cpp" line="29"/>
         <source>Edit event</source>
         <translation>Muokkaa tapahtumaa</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="87"/>
+        <location filename="../EventEditDialog.cpp" line="32"/>
         <source>New event</source>
         <translation>Uusi tapahtuma</translation>
     </message>
@@ -457,38 +457,48 @@ päivä</translation>
         <translation>Hälytys</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="177"/>
+        <location filename="../EventWindow.ui" line="179"/>
         <source>Previous event</source>
         <translation>Edellinen tapahtuma</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="182"/>
+        <location filename="../EventWindow.ui" line="184"/>
         <source>Next event</source>
         <translation>Seuraava tapahtuma</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="187"/>
+        <location filename="../EventWindow.ui" line="189"/>
         <source>Edit event</source>
         <translation>Muokkaa tapahtumaa</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="192"/>
+        <location filename="../EventWindow.ui" line="194"/>
         <source>Delete event</source>
         <translation>Poista tapahtuma</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="139"/>
+        <location filename="../EventWindow.ui" line="199"/>
+        <source>Clone event</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../EventWindow.ui" line="204"/>
+        <source>Automatic links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../EventWindow.cpp" line="145"/>
         <source>From</source>
         <translation>Alkaa</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="139"/>
+        <location filename="../EventWindow.cpp" line="145"/>
         <source>On</source>
         <translation>Ajankohta</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="209"/>
-        <location filename="../EventWindow.cpp" line="230"/>
+        <location filename="../EventWindow.cpp" line="215"/>
+        <location filename="../EventWindow.cpp" line="236"/>
         <source>No more events</source>
         <translation type="unfinished"></translation>
     </message>
@@ -607,11 +617,12 @@ päivä</translation>
     <name>QObject</name>
     <message>
         <location filename="../ChangeManager.cpp" line="120"/>
+        <location filename="../ChangeManager.cpp" line="143"/>
         <source>Unable to edit birthdays</source>
         <translation>Syntymäpäivien muokkaus ei mahdollista</translation>
     </message>
     <message>
-        <location filename="../ChangeManager.cpp" line="130"/>
+        <location filename="../ChangeManager.cpp" line="158"/>
         <source>Delete component?</source>
         <translation>Poista komponentti?</translation>
     </message>
@@ -850,12 +861,12 @@ päivä</translation>
         <translation>Kuvaus</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.cpp" line="45"/>
+        <location filename="../TodoEditDialog.cpp" line="27"/>
         <source>Edit task</source>
         <translation>Muokkaa tehtävää</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.cpp" line="62"/>
+        <location filename="../TodoEditDialog.cpp" line="30"/>
         <source>New task</source>
         <translation>Uusi tehtävä</translation>
     </message>
@@ -883,15 +894,25 @@ päivä</translation>
         <translation>Hälytys</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.ui" line="167"/>
+        <location filename="../TodoWindow.ui" line="169"/>
         <source>Edit task</source>
         <translation>Muokkaa tehtävää</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.ui" line="172"/>
+        <location filename="../TodoWindow.ui" line="174"/>
         <source>Delete task</source>
         <translation>Poista tehtävä</translation>
     </message>
+    <message>
+        <location filename="../TodoWindow.ui" line="179"/>
+        <source>Clone task</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TodoWindow.ui" line="184"/>
+        <source>Automatic links</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TodosPlug</name>
