@@ -431,12 +431,12 @@ dzień</translation>
         <translation>Opis</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="69"/>
+        <location filename="../EventEditDialog.cpp" line="29"/>
         <source>Edit event</source>
         <translation>Edytuj zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="87"/>
+        <location filename="../EventEditDialog.cpp" line="32"/>
         <source>New event</source>
         <translation>Nowe zdarzenie</translation>
     </message>
@@ -464,38 +464,48 @@ dzień</translation>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="177"/>
+        <location filename="../EventWindow.ui" line="179"/>
         <source>Previous event</source>
         <translation>Poprzednie zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="182"/>
+        <location filename="../EventWindow.ui" line="184"/>
         <source>Next event</source>
         <translation>Następne zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="187"/>
+        <location filename="../EventWindow.ui" line="189"/>
         <source>Edit event</source>
         <translation>Edytuj zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="192"/>
+        <location filename="../EventWindow.ui" line="194"/>
         <source>Delete event</source>
         <translation>Usuń zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="139"/>
+        <location filename="../EventWindow.ui" line="199"/>
+        <source>Clone event</source>
+        <translation>Powiel zdarzenie</translation>
+    </message>
+    <message>
+        <location filename="../EventWindow.ui" line="204"/>
+        <source>Automatic links</source>
+        <translation>Automatyczne linki</translation>
+    </message>
+    <message>
+        <location filename="../EventWindow.cpp" line="145"/>
         <source>From</source>
         <translation>Od</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="139"/>
+        <location filename="../EventWindow.cpp" line="145"/>
         <source>On</source>
         <translation>Dnia</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="209"/>
-        <location filename="../EventWindow.cpp" line="230"/>
+        <location filename="../EventWindow.cpp" line="215"/>
+        <location filename="../EventWindow.cpp" line="236"/>
         <source>No more events</source>
         <translation>Nie ma więcej zdarzeń</translation>
     </message>
@@ -614,11 +624,12 @@ dzień</translation>
     <name>QObject</name>
     <message>
         <location filename="../ChangeManager.cpp" line="120"/>
+        <location filename="../ChangeManager.cpp" line="143"/>
         <source>Unable to edit birthdays</source>
         <translation>Nie można edytować urodzin</translation>
     </message>
     <message>
-        <location filename="../ChangeManager.cpp" line="130"/>
+        <location filename="../ChangeManager.cpp" line="158"/>
         <source>Delete component?</source>
         <translation>Usunąć obiekt?</translation>
     </message>
@@ -860,12 +871,12 @@ dzień</translation>
         <translation>Opis</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.cpp" line="45"/>
+        <location filename="../TodoEditDialog.cpp" line="27"/>
         <source>Edit task</source>
         <translation>Edytuj zadanie</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.cpp" line="62"/>
+        <location filename="../TodoEditDialog.cpp" line="30"/>
         <source>New task</source>
         <translation>Nowe zadanie</translation>
     </message>
@@ -893,15 +904,25 @@ dzień</translation>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.ui" line="167"/>
+        <location filename="../TodoWindow.ui" line="169"/>
         <source>Edit task</source>
         <translation>Edytuj zadanie</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.ui" line="172"/>
+        <location filename="../TodoWindow.ui" line="174"/>
         <source>Delete task</source>
         <translation>Usuń zadanie</translation>
     </message>
+    <message>
+        <location filename="../TodoWindow.ui" line="179"/>
+        <source>Clone task</source>
+        <translation>Powiel zadanie</translation>
+    </message>
+    <message>
+        <location filename="../TodoWindow.ui" line="184"/>
+        <source>Automatic links</source>
+        <translation>Automatyczne linki</translation>
+    </message>
 </context>
 <context>
     <name>TodosPlug</name>
